==> haskell-json-ast-0.3.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-json-ast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json-ast
version: 0.3.1
id: json-ast-0.3.1-4J39n8AmpyU6xft9YIlCRG
key: json-ast-0.3.1-4J39n8AmpyU6xft9YIlCRG
license: MIT
copyright: (c) 2016, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/json-ast
synopsis: Universal JSON AST datastructure
abi: 184115be79772908891fced8445f6154
exposed: True
exposed-modules:
    JSONAST
import-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/json-ast-0.3.1
hs-libraries: HSjson-ast-0.3.1-4J39n8AmpyU6xft9YIlCRG
depends:
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq text-1.2.3.0
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo base-4.11.1.0
abi-depends: vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo=64a561e4e9a96e6da50de53181f89cb1
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html: /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-ast-0.3.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-json-ast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json-ast
version: 0.3.1
id: json-ast-0.3.1-DQbyD71hZBd2Y5Ri9UQpaG
key: json-ast-0.3.1-DQbyD71hZBd2Y5Ri9UQpaG
license: MIT
copyright: (c) 2016, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/json-ast
synopsis: Universal JSON AST datastructure
abi: 1dbf34701a36b6c1a2d6761ef17b2b52
exposed: True
exposed-modules:
    JSONAST
import-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/json-ast-0.3.1
hs-libraries: HSjson-ast-0.3.1-DQbyD71hZBd2Y5Ri9UQpaG
depends:
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq text-1.2.3.0
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj base-4.11.1.0
abi-depends: vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=a9e5116cfd8f4e8564ae54d9515a25b1
             unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj=c333847eb697e0b9a0c6f4333fc78402
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html: /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
